@@ -41,6 +41,7 @@
 // Qt
 #include <QApplication>
 #include <QDate>
+#include <QDateTime>
 #include <QCheckBox>
 #include <QClipboard>
 #include <QColorDialog>
@@ -327,13 +328,14 @@ int main(int argc, char *argv[])
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("format"), i18n("Allow --getcolor to specify output format"), QStringLiteral("text")));
     // TODO gauge stuff, reading values from stdin
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("title"), i18n("Dialog title"), QStringLiteral("text")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("default"), i18n("Default entry to use for combobox, menu and color"), QStringLiteral("text")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("default"), i18n("Default entry to use for combobox, menu, color, and calendar"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("multiple"), i18n("Allows the --getopenurl and --getopenfilename options to return multiple files")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("separate-output"), i18n("Return list items on separate lines (for checklist option and file open with --multiple)")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("print-winid"), i18n("Outputs the winId of each dialog")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("dontagain"), i18n("Config file and option name for saving the \"do-not-show/ask-again\" state"),
     QStringLiteral("file:entry")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("slider"), i18n("Slider dialog box, returns selected value"), QStringLiteral("text")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("dateformat"), i18n("Date format for calendar result and/or default value (Qt-style); defaults to 'ddd MMM d yyyy'"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("calendar"), i18n("Calendar dialog box, returns selected date"), QStringLiteral("text")));
     /* kdialog originally used --embed for attaching the dialog box.  However this is misleading and so we changed to --attach.
      * For backwards compatibility, we silently map --embed to --attach */
@@ -1068,13 +1070,27 @@ int main(int argc, char *argv[])
         }
         return returnCode;
     }
+
+    // --calendar text [--default default] [--dateformat format]
     if (parser.isSet(QStringLiteral("calendar"))) {
+        // The default format is weird and non-standard. Sadly, it's too late to change this now.
+        QString dateFormat = QStringLiteral("ddd MMM d yyyy");
+        if (parser.isSet(QStringLiteral("dateformat"))) {
+            dateFormat = parser.value(QStringLiteral("dateformat"));
+        }
+
+        QDate defaultDate = QDateTime::currentDateTime().date(); // today
+        if (parser.isSet(QStringLiteral("default"))) {
+            defaultEntry = parser.value(QStringLiteral("default"));
+            defaultDate = QDate::fromString(defaultEntry, dateFormat);
+        }
+
         const QString text = Utils::parseString(parser.value(QStringLiteral("calendar")));
         QDate result;
 
-        const bool returnCode = Widgets::calendar(nullptr, title, text, result);
+        const bool returnCode = Widgets::calendar(nullptr, title, text, result, defaultDate);
         if (returnCode) {
-            cout << result.toString().toLocal8Bit().data() << endl;
+            cout << result.toString(dateFormat).toLocal8Bit().data() << endl;
         }
         return returnCode;
     }
